package org.apache.bcel.util;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import org.apache.commons.lang3.StringUtils;

public class JavaWrapper {

   private final java.lang.ClassLoader loader;


   private static java.lang.ClassLoader getClassLoader() {
      String s = System.getProperty("bcel.classloader");
      if(StringUtils.isEmpty(s)) {
         throw new IllegalStateException("The property \'bcel.classloader\' must be defined");
      } else {
         try {
            return (java.lang.ClassLoader)Class.forName(s).newInstance();
         } catch (Exception var2) {
            throw new IllegalStateException(var2.toString(), var2);
         }
      }
   }

   public static void main(String[] argv) throws Exception {
      if(argv.length == 0) {
         System.out.println("Missing class name.");
      } else {
         String className = argv[0];
         String[] newArgv = new String[argv.length - 1];
         System.arraycopy(argv, 1, newArgv, 0, newArgv.length);
         (new JavaWrapper()).runMain(className, newArgv);
      }
   }

   public JavaWrapper() {
      this(getClassLoader());
   }

   public JavaWrapper(java.lang.ClassLoader loader) {
      this.loader = loader;
   }

   public void runMain(String className, String[] argv) throws ClassNotFoundException {
      Class cl = this.loader.loadClass(className);
      Method method = null;

      try {
         method = cl.getMethod("main", new Class[]{argv.getClass()});
         int ex = method.getModifiers();
         Class r = method.getReturnType();
         if(!Modifier.isPublic(ex) || !Modifier.isStatic(ex) || Modifier.isAbstract(ex) || r != Void.TYPE) {
            throw new NoSuchMethodException();
         }
      } catch (NoSuchMethodException var8) {
         System.out.println("In class " + className + ": public static void main(String[] argv) is not defined");
         return;
      }

      try {
         method.invoke((Object)null, (Object[])argv);
      } catch (Exception var7) {
         var7.printStackTrace();
      }

   }
}
